==================================
astrodendro.plot.DendrogramPlotter
==================================

.. currentmodule:: astrodendro.plot

.. autoclass:: DendrogramPlotter

   .. rubric:: Methods

   .. autosummary::

      ~DendrogramPlotter.sort
      ~DendrogramPlotter.set_custom_positions
      ~DendrogramPlotter.plot_tree
      ~DendrogramPlotter.plot_contour
      ~DendrogramPlotter.get_lines

   .. rubric:: Methods (detail)

   .. automethod:: DendrogramPlotter.sort
   .. automethod:: DendrogramPlotter.set_custom_positions
   .. automethod:: DendrogramPlotter.plot_tree
   .. automethod:: DendrogramPlotter.plot_contour
   .. automethod:: DendrogramPlotter.get_lines

